@@ -32,7 +32,7 @@ def get_markdown_images_format(text):
     images_list=[]
     for it in text.split("\n"):
         if len(it) >0:
-            it=it.strip().replace(" .",'.').replace(" !",'!').replace(" ;",';').replace(" ?",'?')
+            it=it.strip().replace(" .",'.').replace(" !",'!').replace(" ;",';').replace(" ?",'?').replace(":.",":")
             image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', it)
             if len(image_arr) > 0:
                 images_list.append(image_arr)
@@ -178,13 +178,33 @@ class AutoReWrite(object):
         :return:
         """
         mi=max(int(len(text.split(" "))*0.6),64)
-        payload = {"config": {
-            "do_sample": auto_sample,
-            # "num_beams": 5,
-            "max_length": min(mi,128),
-            "temperature":temperature
-            # "num_return_sequences": 5
-        }, "text": [text]}
+        # payload = {"config": {
+        #     "do_sample": auto_sample,
+        #     # "num_beams": 5,
+        #     "max_length": min(mi,128),
+        #     "temperature":temperature
+        #     # "num_return_sequences": 5
+        # }, "text": [text]}
+        # payload = {"config": {
+        #     "do_sample": auto_sample,
+        #     # "num_beams": 5,
+        #     "max_length": min(mi,128),
+        #     "temperature":temperature
+        #     # "num_return_sequences": 5
+        # }, "text": [text]}
+
+        # 自动调参 https://wandb.ai/terrychanorg/uncategorized/sweeps/j64ghxnf?workspace=user-terrychanorg
+        config={"do_sample": True,
+                    "max_length": min(mi,128),
+                    "early_stopping":True,
+                    "num_return_sequences": 5,
+                    "no_repeat_ngram_size":5,
+                    "num_beams":7,
+                    "temperature":0.8267410332747904,
+                    "top_p":0.9055557526279095}
+        payload={"config":config,
+                 "text": [text]
+                 }
         return self.predict_summary(payload, timeout=600)
         # pass
 
@@ -587,7 +607,7 @@ class AutoReWrite(object):
             # images = get_markdown_images(p)
             if images is None and len(p)>0:
                 # print("p",p)
-                out=self.auto_summary(p,auto_sample=False,temperature=temperature)
+                out=self.auto_summary(p,auto_sample=True,temperature=temperature)
                 try:
                     if out.get("results") and type(out)==dict:
 
